pub struct DisabledModuleFilter {
pub module: Address,
}Fields
module: AddressTrait Implementations
Sourceimpl AbiType for DisabledModuleFilter
impl AbiType for DisabledModuleFilter
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for DisabledModuleFilter
impl Clone for DisabledModuleFilter
Sourcefn clone(&self) -> DisabledModuleFilter
fn clone(&self) -> DisabledModuleFilter
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DisabledModuleFilter
impl Debug for DisabledModuleFilter
Sourceimpl Default for DisabledModuleFilter
impl Default for DisabledModuleFilter
Sourcefn default() -> DisabledModuleFilter
fn default() -> DisabledModuleFilter
Returns the “default value” for a type. Read more
Sourceimpl Display for DisabledModuleFilter
impl Display for DisabledModuleFilter
Sourceimpl EthEvent for DisabledModuleFilter
impl EthEvent for DisabledModuleFilter
Sourcefn signature() -> H256
fn signature() -> H256
Retrieves the signature for the event this data corresponds to.
This signature is the Keccak-256 hash of the ABI signature of
this event.
Sourcefn abi_signature() -> Cow<'static, str>
fn abi_signature() -> Cow<'static, str>
Retrieves the ABI signature for the event this data corresponds
to.
Sourcefn decode_log(log: &RawLog) -> Result<Self, Error>where
Self: Sized,
fn decode_log(log: &RawLog) -> Result<Self, Error>where
Self: Sized,
Decodes an Ethereum
RawLog into an instance of the type.Sourcefn is_anonymous() -> bool
fn is_anonymous() -> bool
Returns true if this is an anonymous event
Sourceimpl From<DisabledModuleFilter> for safeEvents
impl From<DisabledModuleFilter> for safeEvents
Sourcefn from(value: DisabledModuleFilter) -> Self
fn from(value: DisabledModuleFilter) -> Self
Converts to this type from the input type.
Sourceimpl Hash for DisabledModuleFilter
impl Hash for DisabledModuleFilter
Sourceimpl PartialEq for DisabledModuleFilter
impl PartialEq for DisabledModuleFilter
Sourceimpl Tokenizable for DisabledModuleFilter
impl Tokenizable for DisabledModuleFilter
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for DisabledModuleFilter
impl Eq for DisabledModuleFilter
impl StructuralPartialEq for DisabledModuleFilter
impl TokenizableItem for DisabledModuleFilter