pub struct ExecTransactionFromModuleReturnDataCall {
pub to: Address,
pub value: U256,
pub data: Bytes,
pub operation: u8,
}Expand description
Container type for all input parameters for the execTransactionFromModuleReturnData function with signature execTransactionFromModuleReturnData(address,uint256,bytes,uint8) and selector 0x5229073f
Fields
to: Addressvalue: U256data: Bytesoperation: u8Trait Implementations
Sourceimpl AbiType for ExecTransactionFromModuleReturnDataCall
impl AbiType for ExecTransactionFromModuleReturnDataCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for ExecTransactionFromModuleReturnDataCall
impl Clone for ExecTransactionFromModuleReturnDataCall
Sourcefn clone(&self) -> ExecTransactionFromModuleReturnDataCall
fn clone(&self) -> ExecTransactionFromModuleReturnDataCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ExecTransactionFromModuleReturnDataCall
impl Default for ExecTransactionFromModuleReturnDataCall
Sourcefn default() -> ExecTransactionFromModuleReturnDataCall
fn default() -> ExecTransactionFromModuleReturnDataCall
Returns the “default value” for a type. Read more
Sourceimpl From<ExecTransactionFromModuleReturnDataCall> for safeCalls
impl From<ExecTransactionFromModuleReturnDataCall> for safeCalls
Sourcefn from(value: ExecTransactionFromModuleReturnDataCall) -> Self
fn from(value: ExecTransactionFromModuleReturnDataCall) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for ExecTransactionFromModuleReturnDataCall
impl PartialEq for ExecTransactionFromModuleReturnDataCall
Sourcefn eq(&self, other: &ExecTransactionFromModuleReturnDataCall) -> bool
fn eq(&self, other: &ExecTransactionFromModuleReturnDataCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Tokenizable for ExecTransactionFromModuleReturnDataCall
impl Tokenizable for ExecTransactionFromModuleReturnDataCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for ExecTransactionFromModuleReturnDataCall
impl Eq for ExecTransactionFromModuleReturnDataCall
impl StructuralPartialEq for ExecTransactionFromModuleReturnDataCall
impl TokenizableItem for ExecTransactionFromModuleReturnDataCall