pub struct IsModuleEnabledCall {
pub module: Address,
}Expand description
Container type for all input parameters for the isModuleEnabled function with signature isModuleEnabled(address) and selector 0x2d9ad53d
Fields
module: AddressTrait Implementations
Sourceimpl AbiDecode for IsModuleEnabledCall
impl AbiDecode for IsModuleEnabledCall
Sourceimpl AbiEncode for IsModuleEnabledCall
impl AbiEncode for IsModuleEnabledCall
Sourceimpl AbiType for IsModuleEnabledCall
impl AbiType for IsModuleEnabledCall
Sourcefn param_type() -> ParamType
fn param_type() -> ParamType
The native ABI type this type represents.
Sourcefn minimum_size() -> usize
fn minimum_size() -> usize
A hint of the minimum number of bytes this type takes up in the ABI.
Sourceimpl Clone for IsModuleEnabledCall
impl Clone for IsModuleEnabledCall
Sourcefn clone(&self) -> IsModuleEnabledCall
fn clone(&self) -> IsModuleEnabledCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IsModuleEnabledCall
impl Debug for IsModuleEnabledCall
Sourceimpl Default for IsModuleEnabledCall
impl Default for IsModuleEnabledCall
Sourcefn default() -> IsModuleEnabledCall
fn default() -> IsModuleEnabledCall
Returns the “default value” for a type. Read more
Sourceimpl Display for IsModuleEnabledCall
impl Display for IsModuleEnabledCall
Sourceimpl EthCall for IsModuleEnabledCall
impl EthCall for IsModuleEnabledCall
Sourceimpl From<IsModuleEnabledCall> for safeCalls
impl From<IsModuleEnabledCall> for safeCalls
Sourcefn from(value: IsModuleEnabledCall) -> Self
fn from(value: IsModuleEnabledCall) -> Self
Converts to this type from the input type.
Sourceimpl Hash for IsModuleEnabledCall
impl Hash for IsModuleEnabledCall
Sourceimpl PartialEq for IsModuleEnabledCall
impl PartialEq for IsModuleEnabledCall
Sourceimpl Tokenizable for IsModuleEnabledCall
impl Tokenizable for IsModuleEnabledCall
Sourcefn from_token(token: Token) -> Result<Self, InvalidOutputType>
fn from_token(token: Token) -> Result<Self, InvalidOutputType>
Converts a
Token into expected type.Sourcefn into_token(self) -> Token
fn into_token(self) -> Token
Converts a specified type back into token.
impl AbiArrayType for IsModuleEnabledCall
impl Eq for IsModuleEnabledCall
impl StructuralPartialEq for IsModuleEnabledCall
impl TokenizableItem for IsModuleEnabledCall